export default [
    "{ filename: \"src/LowPower.cpp\", code: \"/*******************************************************************************\\n* LowPower Library\\n* Version: 1.81\\n* Date: 21-01-2020\\n* Author: Lim Phang Moh\\n* Company: Rocket Scream Electronics\\n* Website: www.rocketscream.com\\n*\\n* This is a lightweight low power library for Arduino.\\n*\\n* This library is licensed under Creative Commons Attribution-ShareAlike 3.0\\n* Unported License.\\n*\\n* Revision  Description\\n* ========  ===========\\n* 1.81      Fixed timer 2 settings incorrectly restored after sleep.\\n*           Contributed by rwared11.\\n* 1.80      Added support for ATmega88 and ATmega168P. PowerExtStandby()\\n*           modified because not supported on Atmega88 / Atmega168\\n*           Contributed by mrguen.\\n* 1.70      Added support for ATmega644P and ATmega1284P.\\n*           Contributed by alexreinert.\\n* 1.60      Added support for ATmega256RFR2. Contributed by Rodmg.\\n* 1.50      Fixed compiler optimization (Arduino IDE 1.6.x branch) on BOD enable\\n*           function that causes the function to be over optimized.\\n* 1.40\\t\\tAdded support for ATSAMD21G18A.\\n* \\t\\t\\tLibrary format compliant with Arduino IDE 1.5.x.\\n* 1.30\\t\\tAdded support for ATMega168, ATMega2560, ATMega1280 & ATMega32U4.\\n*\\t\\t\\tTested to work with Arduino IDE 1.0.1 - 1.0.4.\\n* 1.20\\t\\tRemove typo error in idle method for checking whether Timer 0 was\\n*\\t\\t\\tturned off.\\n*\\t\\t\\tRemove dependecy on WProgram.h which is not required.\\n*\\t\\t\\tTested to work with Arduino IDE 1.0.\\n* 1.10\\t\\tAdded #ifndef for sleep_bod_disable() for compatibility with future\\n*\\t\\t\\tArduino IDE release.\\n* 1.00      Initial public release.\\n*******************************************************************************/\\n#if defined (__AVR__)\\n\\t#include <avr/sleep.h>\\n\\t#include <avr/wdt.h>\\n\\t#include <avr/power.h>\\n\\t#include <avr/interrupt.h>\\n#elif defined (__arm__)\\n\\n#else\\n\\t#error \\\"Processor architecture is not supported.\\\"\\n#endif\\n\\n#include \\\"LowPower.h\\\"\\n\\n#if defined (__AVR__)\\n// Only Pico Power devices can change BOD settings through software\\n#if defined (__AVR_ATmega328P__) || defined (__AVR_ATmega168P__)\\n#ifndef sleep_bod_disable\\n#define sleep_bod_disable() \\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\\\\\ndo { \\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\\\\\n  unsigned char tempreg; \\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\\\\\n  __asm__ __volatile__(\\\"in %[tempreg], %[mcucr]\\\" \\\"\\\\n\\\\t\\\" \\t\\t\\t\\\\\\n                       \\\"ori %[tempreg], %[bods_bodse]\\\" \\\"\\\\n\\\\t\\\" \\t\\t\\\\\\n                       \\\"out %[mcucr], %[tempreg]\\\" \\\"\\\\n\\\\t\\\" \\t\\t\\t\\\\\\n                       \\\"andi %[tempreg], %[not_bodse]\\\" \\\"\\\\n\\\\t\\\" \\t\\t\\\\\\n                       \\\"out %[mcucr], %[tempreg]\\\" \\t\\t\\t\\t\\t\\\\\\n                       : [tempreg] \\\"=&d\\\" (tempreg) \\t\\t\\t\\t\\t\\\\\\n                       : [mcucr] \\\"I\\\" _SFR_IO_ADDR(MCUCR), \\t\\t\\t\\\\\\n                         [bods_bodse] \\\"i\\\" (_BV(BODS) | _BV(BODSE)), \\\\\\n                         [not_bodse] \\\"i\\\" (~_BV(BODSE))); \\t\\t\\t\\\\\\n} while (0)\\n#endif\\n#endif\\n\\n#define\\tlowPowerBodOn(mode)\\t\\\\\\ndo { \\t\\t\\t\\t\\t\\t\\\\\\n      set_sleep_mode(mode); \\\\\\n      cli();\\t\\t\\t\\t\\\\\\n      sleep_enable();\\t\\t\\\\\\n      sei();\\t\\t\\t\\t\\\\\\n      sleep_cpu();\\t\\t\\t\\\\\\n      sleep_disable();\\t\\t\\\\\\n      sei();\\t\\t\\t\\t\\\\\\n} while (0);\\n\\n// Only Pico Power devices can change BOD settings through software\\n#if defined (__AVR_ATmega328P__) || defined (__AVR_ATmega168P__) || defined(__AVR_ATmega644P__) || defined(__AVR_ATmega1284P__)\\n#define\\tlowPowerBodOff(mode)\\\\\\ndo { \\t\\t\\t\\t\\t\\t\\\\\\n      set_sleep_mode(mode); \\\\\\n      cli();\\t\\t\\t\\t\\\\\\n      sleep_enable();\\t\\t\\\\\\n\\t\\t\\tsleep_bod_disable(); \\\\\\n      sei();\\t\\t\\t\\t\\\\\\n      sleep_cpu();\\t\\t\\t\\\\\\n      sleep_disable();\\t\\t\\\\\\n      sei();\\t\\t\\t\\t\\\\\\n} while (0);\\n#endif\\n\\n// Some macros is still missing from AVR GCC distribution for ATmega32U4\\n#if defined __AVR_ATmega32U4__\\n\\t// Timer 4 PRR bit is currently not defined in iom32u4.h\\n\\t#ifndef PRTIM4\\n\\t\\t#define PRTIM4 4\\n\\t#endif\\n\\n\\t// Timer 4 power reduction macro is not defined currently in power.h\\n\\t#ifndef power_timer4_disable\\n\\t\\t#define power_timer4_disable()\\t(PRR1 |= (uint8_t)(1 << PRTIM4))\\n\\t#endif\\n\\n\\t#ifndef power_timer4_enable\\n\\t\\t#define power_timer4_enable()\\t\\t(PRR1 &= (uint8_t)~(1 << PRTIM4))\\n\\t#endif\\n#endif\\n\\n/*******************************************************************************\\n* Name: idle\\n* Description: Putting ATmega328P/168 into idle state. Please make sure you\\n*\\t\\t\\t         understand the implication and result of disabling module.\\n*\\n* Argument  \\tDescription\\n* =========  \\t===========\\n* 1. period   Duration of low power mode. Use SLEEP_FOREVER to use other wake\\n*\\t\\t\\t\\tup resource:\\n*\\t\\t\\t\\t(a) SLEEP_15MS - 15 ms sleep\\n*\\t\\t\\t\\t(b) SLEEP_30MS - 30 ms sleep\\n*\\t\\t\\t\\t(c) SLEEP_60MS - 60 ms sleep\\n*\\t\\t\\t\\t(d) SLEEP_120MS - 120 ms sleep\\n*\\t\\t\\t\\t(e) SLEEP_250MS - 250 ms sleep\\n*\\t\\t\\t\\t(f) SLEEP_500MS - 500 ms sleep\\n*\\t\\t\\t\\t(g) SLEEP_1S - 1 s sleep\\n*\\t\\t\\t\\t(h) SLEEP_2S - 2 s sleep\\n*\\t\\t\\t\\t(i) SLEEP_4S - 4 s sleep\\n*\\t\\t\\t\\t(j) SLEEP_8S - 8 s sleep\\n*\\t\\t\\t\\t(k) SLEEP_FOREVER - Sleep without waking up through WDT\\n*\\n* 2. adc\\t\\tADC module disable control:\\n*\\t\\t\\t\\t(a) ADC_OFF - Turn off ADC module\\n*\\t\\t\\t\\t(b) ADC_ON - Leave ADC module in its default state\\n*\\n* 3. timer2\\t\\tTimer 2 module disable control:\\n*\\t\\t\\t\\t(a) TIMER2_OFF - Turn off Timer 2 module\\n*\\t\\t\\t\\t(b) TIMER2_ON - Leave Timer 2 module in its default state\\n*\\n* 4. timer1\\t\\tTimer 1 module disable control:\\n*\\t\\t\\t\\t(a) TIMER1_OFF - Turn off Timer 1 module\\n*\\t\\t\\t\\t(b) TIMER1_ON - Leave Timer 1 module in its default state\\n*\\n* 5. timer0\\t\\tTimer 0 module disable control:\\n*\\t\\t\\t\\t(a) TIMER0_OFF - Turn off Timer 0 module\\n*\\t\\t\\t\\t(b) TIMER0_ON - Leave Timer 0 module in its default state\\n*\\n* 6. spi\\t\\tSPI module disable control:\\n*\\t\\t\\t\\t(a) SPI_OFF - Turn off SPI module\\n*\\t\\t\\t\\t(b) SPI_ON - Leave SPI module in its default state\\n*\\n* 7. usart0\\t\\tUSART0 module disable control:\\n*\\t\\t\\t\\t(a) USART0_OFF - Turn off USART0  module\\n*\\t\\t\\t\\t(b) USART0_ON - Leave USART0 module in its default state\\n*\\n* 8. twi\\t\\tTWI module disable control:\\n*\\t\\t\\t\\t(a) TWI_OFF - Turn off TWI module\\n*\\t\\t\\t\\t(b) TWI_ON - Leave TWI module in its default state\\n*\\n*******************************************************************************/\\n#if defined (__AVR_ATmega328P__) || defined (__AVR_ATmega168__) || defined (__AVR_ATmega168P__) || defined (__AVR_ATmega88__)\\nvoid\\tLowPowerClass::idle(period_t period, adc_t adc, timer2_t timer2,\\n\\t\\t\\t\\t\\t\\t\\ttimer1_t timer1, timer0_t timer0,\\n\\t\\t\\t\\t\\t\\t\\tspi_t spi, usart0_t usart0,\\ttwi_t twi)\\n{\\n\\t// Temporary clock source variable\\n\\tunsigned char clockSource = 0;\\n\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n\\t\\t// Store current setting\\n        clockSource = TCCR2B;\\n\\n\\t\\t// Remove the clock source to shutdown Timer2\\n\\t\\tTCCR2B &= ~(1 << CS22);\\n\\t\\tTCCR2B &= ~(1 << CS21);\\n\\t\\tTCCR2B &= ~(1 << CS20);\\n\\n\\t\\tpower_timer2_disable();\\n\\t}\\n\\n\\tif (adc == ADC_OFF)\\n\\t{\\n\\t\\tADCSRA &= ~(1 << ADEN);\\n\\t\\tpower_adc_disable();\\n\\t}\\n\\n\\tif (timer1 == TIMER1_OFF)\\tpower_timer1_disable();\\n\\tif (timer0 == TIMER0_OFF)\\tpower_timer0_disable();\\n\\tif (spi == SPI_OFF)\\t\\t\\tpower_spi_disable();\\n\\tif (usart0 == USART0_OFF)\\tpower_usart0_disable();\\n\\tif (twi == TWI_OFF)\\t\\t\\tpower_twi_disable();\\n\\n\\tif (period != SLEEP_FOREVER)\\n\\t{\\n\\t\\twdt_enable(period);\\n\\t\\tWDTCSR |= (1 << WDIE);\\n\\t}\\n\\n\\tlowPowerBodOn(SLEEP_MODE_IDLE);\\n\\n\\tif (adc == ADC_OFF)\\n\\t{\\n\\t\\tpower_adc_enable();\\n\\t\\tADCSRA |= (1 << ADEN);\\n\\t}\\n\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n        // Restore previous setting\\n        TCCR2B = clockSource;\\n        \\n\\t\\tpower_timer2_enable();\\n\\t}\\n\\n\\tif (timer1 == TIMER1_OFF)\\tpower_timer1_enable();\\n\\tif (timer0 == TIMER0_OFF)\\tpower_timer0_enable();\\n\\tif (spi == SPI_OFF)\\t\\t\\tpower_spi_enable();\\n\\tif (usart0 == USART0_OFF)\\tpower_usart0_enable();\\n\\tif (twi == TWI_OFF)\\t\\t\\tpower_twi_enable();\\n}\\n#endif\\n\\n/*******************************************************************************\\n* Name: idle\\n* Description: Putting ATmega32U4 into idle state. Please make sure you\\n*\\t\\t\\t   understand the implication and result of disabling module.\\n*\\t\\t\\t   Take note that Timer 2 is not available and USART0 is replaced\\n* \\t\\t\\t   with USART1 on ATmega32U4.\\n*\\n* Argument  \\tDescription\\n* =========  \\t===========\\n* 1. period     Duration of low power mode. Use SLEEP_FOREVER to use other wake\\n*\\t\\t\\t\\tup resource:\\n*\\t\\t\\t\\t(a) SLEEP_15MS - 15 ms sleep\\n*\\t\\t\\t\\t(b) SLEEP_30MS - 30 ms sleep\\n*\\t\\t\\t\\t(c) SLEEP_60MS - 60 ms sleep\\n*\\t\\t\\t\\t(d) SLEEP_120MS - 120 ms sleep\\n*\\t\\t\\t\\t(e) SLEEP_250MS - 250 ms sleep\\n*\\t\\t\\t\\t(f) SLEEP_500MS - 500 ms sleep\\n*\\t\\t\\t\\t(g) SLEEP_1S - 1 s sleep\\n*\\t\\t\\t\\t(h) SLEEP_2S - 2 s sleep\\n*\\t\\t\\t\\t(i) SLEEP_4S - 4 s sleep\\n*\\t\\t\\t\\t(j) SLEEP_8S - 8 s sleep\\n*\\t\\t\\t\\t(k) SLEEP_FOREVER - Sleep without waking up through WDT\\n*\\n* 2. adc\\t\\tADC module disable control:\\n*\\t\\t\\t\\t(a) ADC_OFF - Turn off ADC module\\n*\\t\\t\\t\\t(b) ADC_ON - Leave ADC module in its default state\\n*\\n* 3. timer4\\t\\tTimer 4 module disable control:\\n*\\t\\t\\t\\t(a) TIMER4_OFF - Turn off Timer 4 module\\n*\\t\\t\\t\\t(b) TIMER4_ON - Leave Timer 4 module in its default state\\n*\\n* 4. timer3\\t\\tTimer 3 module disable control:\\n*\\t\\t\\t\\t(a) TIMER3_OFF - Turn off Timer 3 module\\n*\\t\\t\\t\\t(b) TIMER3_ON - Leave Timer 3 module in its default state\\n*\\n* 5. timer1\\t\\tTimer 1 module disable control:\\n*\\t\\t\\t\\t(a) TIMER1_OFF - Turn off Timer 1 module\\n*\\t\\t\\t\\t(b) TIMER1_ON - Leave Timer 1 module in its default state\\n*\\n* 6. timer0\\t\\tTimer 0 module disable control:\\n*\\t\\t\\t\\t(a) TIMER0_OFF - Turn off Timer 0 module\\n*\\t\\t\\t\\t(b) TIMER0_ON - Leave Timer 0 module in its default state\\n*\\n* 7. spi\\t\\tSPI module disable control:\\n*\\t\\t\\t\\t(a) SPI_OFF - Turn off SPI module\\n*\\t\\t\\t\\t(b) SPI_ON - Leave SPI module in its default state\\n*\\n* 8. usart1\\t\\tUSART1 module disable control:\\n*\\t\\t\\t\\t(a) USART1_OFF - Turn off USART1  module\\n*\\t\\t\\t\\t(b) USART1_ON - Leave USART1 module in its default state\\n*\\n* 9. twi\\t\\tTWI module disable control:\\n*\\t\\t\\t\\t(a) TWI_OFF - Turn off TWI module\\n*\\t\\t\\t\\t(b) TWI_ON - Leave TWI module in its default state\\n*\\n* 10.usb\\t\\tUSB module disable control:\\n*\\t\\t\\t\\t(a) USB_OFF - Turn off USB module\\n*\\t\\t\\t\\t(b) USB_ON - Leave USB module in its default state\\n*******************************************************************************/\\n#if defined __AVR_ATmega32U4__\\nvoid\\tLowPowerClass::idle(period_t period, adc_t adc,\\n\\t\\t\\t\\t\\t\\t\\ttimer4_t timer4, timer3_t timer3,\\n\\t\\t\\t\\t\\t\\t\\ttimer1_t timer1, timer0_t timer0,\\n\\t\\t\\t\\t\\t\\t\\tspi_t spi, usart1_t usart1,\\ttwi_t twi, usb_t usb)\\n{\\n\\tif (adc == ADC_OFF)\\n\\t{\\n\\t\\tADCSRA &= ~(1 << ADEN);\\n\\t\\tpower_adc_disable();\\n\\t}\\n\\n\\tif (timer4 == TIMER4_OFF)\\tpower_timer4_disable();\\n\\tif (timer3 == TIMER3_OFF)\\tpower_timer3_disable();\\n\\tif (timer1 == TIMER1_OFF)\\tpower_timer1_disable();\\n\\tif (timer0 == TIMER0_OFF)\\tpower_timer0_disable();\\n\\tif (spi == SPI_OFF)\\t\\t\\tpower_spi_disable();\\n\\tif (usart1 == USART1_OFF)\\tpower_usart1_disable();\\n\\tif (twi == TWI_OFF)\\t\\t\\tpower_twi_disable();\\n\\tif (usb == USB_OFF)\\t\\t\\tpower_usb_disable();\\n\\n\\tif (period != SLEEP_FOREVER)\\n\\t{\\n\\t\\twdt_enable(period);\\n\\t\\tWDTCSR |= (1 << WDIE);\\n\\t}\\n\\n\\tlowPowerBodOn(SLEEP_MODE_IDLE);\\n\\n\\tif (adc == ADC_OFF)\\n\\t{\\n\\t\\tpower_adc_enable();\\n\\t\\tADCSRA |= (1 << ADEN);\\n\\t}\\n\\n\\tif (timer4 == TIMER4_OFF)\\tpower_timer4_enable();\\n\\tif (timer3 == TIMER3_OFF)\\tpower_timer3_enable();\\n\\tif (timer1 == TIMER1_OFF)\\tpower_timer1_enable();\\n\\tif (timer0 == TIMER0_OFF)\\tpower_timer0_enable();\\n\\tif (spi == SPI_OFF)\\t\\t\\tpower_spi_enable();\\n\\tif (usart1 == USART1_OFF)\\tpower_usart1_enable();\\n\\tif (twi == TWI_OFF)\\t\\t\\tpower_twi_enable();\\n\\tif (usb == USB_OFF)\\t\\t\\tpower_usb_enable();\\n}\\n#endif\\n\\n/*******************************************************************************\\n* Name: idle\\n* Description: Putting ATmega644P & ATmega1284P into idle state. Please make sure\\n*\\t\\t\\t   you understand the implication and result of disabling module.\\n*\\t\\t\\t   Take note that extra USART 1 compared to an ATmega328P/168.\\n*\\n* Argument  \\tDescription\\n* =========  \\t===========\\n* 1. period     Duration of low power mode. Use SLEEP_FOREVER to use other wake\\n*\\t\\t\\t\\tup resource:\\n*\\t\\t\\t\\t(a) SLEEP_15MS - 15 ms sleep\\n*\\t\\t\\t\\t(b) SLEEP_30MS - 30 ms sleep\\n*\\t\\t\\t\\t(c) SLEEP_60MS - 60 ms sleep\\n*\\t\\t\\t\\t(d) SLEEP_120MS - 120 ms sleep\\n*\\t\\t\\t\\t(e) SLEEP_250MS - 250 ms sleep\\n*\\t\\t\\t\\t(f) SLEEP_500MS - 500 ms sleep\\n*\\t\\t\\t\\t(g) SLEEP_1S - 1 s sleep\\n*\\t\\t\\t\\t(h) SLEEP_2S - 2 s sleep\\n*\\t\\t\\t\\t(i) SLEEP_4S - 4 s sleep\\n*\\t\\t\\t\\t(j) SLEEP_8S - 8 s sleep\\n*\\t\\t\\t\\t(k) SLEEP_FOREVER - Sleep without waking up through WDT\\n*\\n* 2. adc\\t\\tADC module disable control:\\n*\\t\\t\\t\\t(a) ADC_OFF - Turn off ADC module\\n*\\t\\t\\t\\t(b) ADC_ON - Leave ADC module in its default state\\n*\\n* 3. timer2\\t\\tTimer 2 module disable control:\\n*\\t\\t\\t\\t(a) TIMER2_OFF - Turn off Timer 2 module\\n*\\t\\t\\t\\t(b) TIMER2_ON - Leave Timer 2 module in its default state\\n*\\n* 4. timer1\\t\\tTimer 1 module disable control:\\n*\\t\\t\\t\\t(a) TIMER1_OFF - Turn off Timer 1 module\\n*\\t\\t\\t\\t(b) TIMER1_ON - Leave Timer 1 module in its default state\\n*\\n* 5. timer0\\t\\tTimer 0 module disable control:\\n*\\t\\t\\t\\t(a) TIMER0_OFF - Turn off Timer 0 module\\n*\\t\\t\\t\\t(b) TIMER0_ON - Leave Timer 0 module in its default state\\n*\\n* 6. spi\\t\\tSPI module disable control:\\n*\\t\\t\\t\\t(a) SPI_OFF - Turn off SPI module\\n*\\t\\t\\t\\t(b) SPI_ON - Leave SPI module in its default state\\n*\\n* 7. usart1\\t\\tUSART1 module disable control:\\n*\\t\\t\\t\\t(a) USART1_OFF - Turn off USART1  module\\n*\\t\\t\\t\\t(b) USART1_ON - Leave USART1 module in its default state\\n*\\n* 8. usart0\\t\\tUSART0 module disable control:\\n*\\t\\t\\t\\t(a) USART0_OFF - Turn off USART0  module\\n*\\t\\t\\t\\t(b) USART0_ON - Leave USART0 module in its default state\\n*\\n* 9. twi\\t\\tTWI module disable control:\\n*\\t\\t\\t\\t(a) TWI_OFF - Turn off TWI module\\n*\\t\\t\\t\\t(b) TWI_ON - Leave TWI module in its default state\\n*\\n*******************************************************************************/\\n#if defined (__AVR_ATmega644P__) || defined (__AVR_ATmega1284P__)\\nvoid\\tLowPowerClass::idle(period_t period, adc_t adc, timer2_t timer2,\\n\\t\\t\\t\\t\\t\\t\\ttimer1_t timer1, timer0_t timer0, spi_t spi,\\n\\t\\t\\t\\t\\t\\t\\tusart1_t usart1, usart0_t usart0, twi_t twi)\\n{\\n\\t// Temporary clock source variable\\n\\tunsigned char clockSource = 0;\\n\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n\\t\\t// Store current setting\\n        clockSource = TCCR2B;\\n\\n\\t\\t// Remove the clock source to shutdown Timer2\\n\\t\\tTCCR2B &= ~(1 << CS22);\\n\\t\\tTCCR2B &= ~(1 << CS21);\\n\\t\\tTCCR2B &= ~(1 << CS20);\\n\\n\\t\\tpower_timer2_disable();\\n\\t}\\n\\n\\tif (adc == ADC_OFF)\\n\\t{\\n\\t\\tADCSRA &= ~(1 << ADEN);\\n\\t\\tpower_adc_disable();\\n\\t}\\n\\n\\tif (timer1 == TIMER1_OFF)\\tpower_timer1_disable();\\n\\tif (timer0 == TIMER0_OFF)\\tpower_timer0_disable();\\n\\tif (spi == SPI_OFF)\\t\\t    power_spi_disable();\\n\\tif (usart1 == USART1_OFF)\\tpower_usart1_disable();\\n\\tif (usart0 == USART0_OFF)\\tpower_usart0_disable();\\n\\tif (twi == TWI_OFF)\\t\\t\\tpower_twi_disable();\\n\\n\\tif (period != SLEEP_FOREVER)\\n\\t{\\n\\t\\twdt_enable(period);\\n\\t\\tWDTCSR |= (1 << WDIE);\\n\\t}\\n\\n\\tlowPowerBodOn(SLEEP_MODE_IDLE);\\n\\n\\tif (adc == ADC_OFF)\\n\\t{\\n\\t\\tpower_adc_enable();\\n\\t\\tADCSRA |= (1 << ADEN);\\n\\t}\\n\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n        // Restore previous setting\\n        TCCR2B = clockSource;\\n\\n\\t\\tpower_timer2_enable();\\n\\t}\\n\\n\\tif (timer1 == TIMER1_OFF)\\tpower_timer1_enable();\\n\\tif (timer0 == TIMER0_OFF)\\tpower_timer0_enable();\\n\\tif (spi == SPI_OFF)\\t\\t\\tpower_spi_enable();\\n\\tif (usart1 == USART1_OFF)\\tpower_usart1_enable();\\n\\tif (usart0 == USART0_OFF)\\tpower_usart0_enable();\\n\\tif (twi == TWI_OFF)\\t\\t\\tpower_twi_enable();\\n}\\n#endif\\n\\n/*******************************************************************************\\n* Name: idle\\n* Description: Putting ATmega2560 & ATmega1280 into idle state. Please make sure\\n*\\t\\t\\t   you understand the implication and result of disabling module.\\n*\\t\\t\\t   Take note that extra Timer 5, 4, 3 compared to an ATmega328P/168.\\n*\\t\\t\\t   Also take note that extra USART 3, 2, 1 compared to an\\n*\\t\\t\\t   ATmega328P/168.\\n*\\n* Argument  \\tDescription\\n* =========  \\t===========\\n* 1. period     Duration of low power mode. Use SLEEP_FOREVER to use other wake\\n*\\t\\t\\t\\tup resource:\\n*\\t\\t\\t\\t(a) SLEEP_15MS - 15 ms sleep\\n*\\t\\t\\t\\t(b) SLEEP_30MS - 30 ms sleep\\n*\\t\\t\\t\\t(c) SLEEP_60MS - 60 ms sleep\\n*\\t\\t\\t\\t(d) SLEEP_120MS - 120 ms sleep\\n*\\t\\t\\t\\t(e) SLEEP_250MS - 250 ms sleep\\n*\\t\\t\\t\\t(f) SLEEP_500MS - 500 ms sleep\\n*\\t\\t\\t\\t(g) SLEEP_1S - 1 s sleep\\n*\\t\\t\\t\\t(h) SLEEP_2S - 2 s sleep\\n*\\t\\t\\t\\t(i) SLEEP_4S - 4 s sleep\\n*\\t\\t\\t\\t(j) SLEEP_8S - 8 s sleep\\n*\\t\\t\\t\\t(k) SLEEP_FOREVER - Sleep without waking up through WDT\\n*\\n* 2. adc\\t\\tADC module disable control:\\n*\\t\\t\\t\\t(a) ADC_OFF - Turn off ADC module\\n*\\t\\t\\t\\t(b) ADC_ON - Leave ADC module in its default state\\n*\\n* 3. timer5\\t\\tTimer 5 module disable control:\\n*\\t\\t\\t\\t(a) TIMER5_OFF - Turn off Timer 5 module\\n*\\t\\t\\t\\t(b) TIMER5_ON - Leave Timer 5 module in its default state\\n*\\n* 4. timer4\\t\\tTimer 4 module disable control:\\n*\\t\\t\\t\\t(a) TIMER4_OFF - Turn off Timer 4 module\\n*\\t\\t\\t\\t(b) TIMER4_ON - Leave Timer 4 module in its default state\\n*\\n* 5. timer3\\t\\tTimer 3 module disable control:\\n*\\t\\t\\t\\t(a) TIMER3_OFF - Turn off Timer 3 module\\n*\\t\\t\\t\\t(b) TIMER3_ON - Leave Timer 3 module in its default state\\n*\\n* 6. timer2\\t\\tTimer 2 module disable control:\\n*\\t\\t\\t\\t(a) TIMER2_OFF - Turn off Timer 2 module\\n*\\t\\t\\t\\t(b) TIMER2_ON - Leave Timer 2 module in its default state\\n*\\n* 7. timer1\\t\\tTimer 1 module disable control:\\n*\\t\\t\\t\\t(a) TIMER1_OFF - Turn off Timer 1 module\\n*\\t\\t\\t\\t(b) TIMER1_ON - Leave Timer 1 module in its default state\\n*\\n* 8. timer0\\t\\tTimer 0 module disable control:\\n*\\t\\t\\t\\t(a) TIMER0_OFF - Turn off Timer 0 module\\n*\\t\\t\\t\\t(b) TIMER0_ON - Leave Timer 0 module in its default state\\n*\\n* 9. spi\\t\\tSPI module disable control:\\n*\\t\\t\\t\\t(a) SPI_OFF - Turn off SPI module\\n*\\t\\t\\t\\t(b) SPI_ON - Leave SPI module in its default state\\n*\\n* 10.usart3\\t\\tUSART3 module disable control:\\n*\\t\\t\\t\\t(a) USART3_OFF - Turn off USART3  module\\n*\\t\\t\\t\\t(b) USART3_ON - Leave USART3 module in its default state\\n*\\n* 11.usart2\\t\\tUSART2 module disable control:\\n*\\t\\t\\t\\t(a) USART2_OFF - Turn off USART2  module\\n*\\t\\t\\t\\t(b) USART2_ON - Leave USART2 module in its default state\\n*\\n* 12.usart1\\t\\tUSART1 module disable control:\\n*\\t\\t\\t\\t(a) USART1_OFF - Turn off USART1  module\\n*\\t\\t\\t\\t(b) USART1_ON - Leave USART1 module in its default state\\n*\\n* 13.usart0\\t\\tUSART0 module disable control:\\n*\\t\\t\\t\\t(a) USART0_OFF - Turn off USART0  module\\n*\\t\\t\\t\\t(b) USART0_ON - Leave USART0 module in its default state\\n*\\n* 14.twi\\t\\tTWI module disable control:\\n*\\t\\t\\t\\t(a) TWI_OFF - Turn off TWI module\\n*\\t\\t\\t\\t(b) TWI_ON - Leave TWI module in its default state\\n*\\n*******************************************************************************/\\n#if defined (__AVR_ATmega2560__) || defined (__AVR_ATmega1280__)\\nvoid\\tLowPowerClass::idle(period_t period, adc_t adc, timer5_t timer5,\\n\\t\\t\\t\\t\\t        timer4_t timer4, timer3_t timer3, timer2_t timer2,\\n\\t\\t\\t\\t\\t\\t\\ttimer1_t timer1, timer0_t timer0, spi_t spi,\\n\\t\\t\\t\\t\\t\\t\\tusart3_t usart3, usart2_t usart2, usart1_t usart1,\\n\\t\\t\\t                usart0_t usart0, twi_t twi)\\n{\\n\\t// Temporary clock source variable\\n\\tunsigned char clockSource = 0;\\n\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n\\t\\t// Store current setting\\n        clockSource = TCCR2B;\\n\\n\\t\\t// Remove the clock source to shutdown Timer2\\n\\t\\tTCCR2B &= ~(1 << CS22);\\n\\t\\tTCCR2B &= ~(1 << CS21);\\n\\t\\tTCCR2B &= ~(1 << CS20);\\n\\n\\t\\tpower_timer2_disable();\\n\\t}\\n\\n\\tif (adc == ADC_OFF)\\n\\t{\\n\\t\\tADCSRA &= ~(1 << ADEN);\\n\\t\\tpower_adc_disable();\\n\\t}\\n\\n\\tif (timer5 == TIMER5_OFF)\\tpower_timer5_disable();\\n\\tif (timer4 == TIMER4_OFF)\\tpower_timer4_disable();\\n\\tif (timer3 == TIMER3_OFF)\\tpower_timer3_disable();\\n\\tif (timer1 == TIMER1_OFF)\\tpower_timer1_disable();\\n\\tif (timer0 == TIMER0_OFF)\\tpower_timer0_disable();\\n\\tif (spi == SPI_OFF)\\t\\t    power_spi_disable();\\n\\tif (usart3 == USART3_OFF)\\tpower_usart3_disable();\\n\\tif (usart2 == USART2_OFF)\\tpower_usart2_disable();\\n\\tif (usart1 == USART1_OFF)\\tpower_usart1_disable();\\n\\tif (usart0 == USART0_OFF)\\tpower_usart0_disable();\\n\\tif (twi == TWI_OFF)\\t\\t\\tpower_twi_disable();\\n\\n\\tif (period != SLEEP_FOREVER)\\n\\t{\\n\\t\\twdt_enable(period);\\n\\t\\tWDTCSR |= (1 << WDIE);\\n\\t}\\n\\n\\tlowPowerBodOn(SLEEP_MODE_IDLE);\\n\\n\\tif (adc == ADC_OFF)\\n\\t{\\n\\t\\tpower_adc_enable();\\n\\t\\tADCSRA |= (1 << ADEN);\\n\\t}\\n\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n        // Restore previous setting\\n        TCCR2B = clockSource;\\n\\n\\t\\tpower_timer2_enable();\\n\\t}\\n\\n\\tif (timer5 == TIMER5_OFF)\\tpower_timer5_enable();\\n\\tif (timer4 == TIMER4_OFF)\\tpower_timer4_enable();\\n\\tif (timer3 == TIMER3_OFF)\\tpower_timer3_enable();\\n\\tif (timer1 == TIMER1_OFF)\\tpower_timer1_enable();\\n\\tif (timer0 == TIMER0_OFF)\\tpower_timer0_enable();\\n\\tif (spi == SPI_OFF)\\t\\t\\tpower_spi_enable();\\n\\tif (usart3 == USART3_OFF)\\tpower_usart3_enable();\\n\\tif (usart2 == USART2_OFF)\\tpower_usart2_enable();\\n\\tif (usart1 == USART1_OFF)\\tpower_usart1_enable();\\n\\tif (usart0 == USART0_OFF)\\tpower_usart0_enable();\\n\\tif (twi == TWI_OFF)\\t\\t\\tpower_twi_enable();\\n}\\n#endif\\n\\n/*******************************************************************************\\n* Name: idle\\n* Description: Putting ATmega256RFR2 into idle state. Please make sure\\n*\\t\\t\\t   you understand the implication and result of disabling module.\\n*\\t\\t\\t   Take note that extra Timer 5, 4, 3 compared to an ATmega328P/168.\\n*\\t\\t\\t   Also take note that extra USART 1 compared to an\\n*\\t\\t\\t   ATmega328P/168.\\n*\\n* Argument  \\tDescription\\n* =========  \\t===========\\n* 1. period     Duration of low power mode. Use SLEEP_FOREVER to use other wake\\n*\\t\\t\\t\\tup resource:\\n*\\t\\t\\t\\t(a) SLEEP_15MS - 15 ms sleep\\n*\\t\\t\\t\\t(b) SLEEP_30MS - 30 ms sleep\\n*\\t\\t\\t\\t(c) SLEEP_60MS - 60 ms sleep\\n*\\t\\t\\t\\t(d) SLEEP_120MS - 120 ms sleep\\n*\\t\\t\\t\\t(e) SLEEP_250MS - 250 ms sleep\\n*\\t\\t\\t\\t(f) SLEEP_500MS - 500 ms sleep\\n*\\t\\t\\t\\t(g) SLEEP_1S - 1 s sleep\\n*\\t\\t\\t\\t(h) SLEEP_2S - 2 s sleep\\n*\\t\\t\\t\\t(i) SLEEP_4S - 4 s sleep\\n*\\t\\t\\t\\t(j) SLEEP_8S - 8 s sleep\\n*\\t\\t\\t\\t(k) SLEEP_FOREVER - Sleep without waking up through WDT\\n*\\n* 2. adc\\t\\tADC module disable control:\\n*\\t\\t\\t\\t(a) ADC_OFF - Turn off ADC module\\n*\\t\\t\\t\\t(b) ADC_ON - Leave ADC module in its default state\\n*\\n* 3. timer5\\t\\tTimer 5 module disable control:\\n*\\t\\t\\t\\t(a) TIMER5_OFF - Turn off Timer 5 module\\n*\\t\\t\\t\\t(b) TIMER5_ON - Leave Timer 5 module in its default state\\n*\\n* 4. timer4\\t\\tTimer 4 module disable control:\\n*\\t\\t\\t\\t(a) TIMER4_OFF - Turn off Timer 4 module\\n*\\t\\t\\t\\t(b) TIMER4_ON - Leave Timer 4 module in its default state\\n*\\n* 5. timer3\\t\\tTimer 3 module disable control:\\n*\\t\\t\\t\\t(a) TIMER3_OFF - Turn off Timer 3 module\\n*\\t\\t\\t\\t(b) TIMER3_ON - Leave Timer 3 module in its default state\\n*\\n* 6. timer2\\t\\tTimer 2 module disable control:\\n*\\t\\t\\t\\t(a) TIMER2_OFF - Turn off Timer 2 module\\n*\\t\\t\\t\\t(b) TIMER2_ON - Leave Timer 2 module in its default state\\n*\\n* 7. timer1\\t\\tTimer 1 module disable control:\\n*\\t\\t\\t\\t(a) TIMER1_OFF - Turn off Timer 1 module\\n*\\t\\t\\t\\t(b) TIMER1_ON - Leave Timer 1 module in its default state\\n*\\n* 8. timer0\\t\\tTimer 0 module disable control:\\n*\\t\\t\\t\\t(a) TIMER0_OFF - Turn off Timer 0 module\\n*\\t\\t\\t\\t(b) TIMER0_ON - Leave Timer 0 module in its default state\\n*\\n* 9. spi\\t\\tSPI module disable control:\\n*\\t\\t\\t\\t(a) SPI_OFF - Turn off SPI module\\n*\\t\\t\\t\\t(b) SPI_ON - Leave SPI module in its default state\\n*\\n* 10.usart1\\t\\tUSART1 module disable control:\\n*\\t\\t\\t\\t(a) USART1_OFF - Turn off USART1  module\\n*\\t\\t\\t\\t(b) USART1_ON - Leave USART1 module in its default state\\n*\\n* 11.usart0\\t\\tUSART0 module disable control:\\n*\\t\\t\\t\\t(a) USART0_OFF - Turn off USART0  module\\n*\\t\\t\\t\\t(b) USART0_ON - Leave USART0 module in its default state\\n*\\n* 12.twi\\t\\tTWI module disable control:\\n*\\t\\t\\t\\t(a) TWI_OFF - Turn off TWI module\\n*\\t\\t\\t\\t(b) TWI_ON - Leave TWI module in its default state\\n*\\n*******************************************************************************/\\n#if defined (__AVR_ATmega256RFR2__)\\nvoid\\tLowPowerClass::idle(period_t period, adc_t adc, timer5_t timer5,\\n\\t\\t\\t\\t\\t                timer4_t timer4, timer3_t timer3, timer2_t timer2,\\n\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\ttimer1_t timer1, timer0_t timer0, spi_t spi,\\n\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t\\tusart1_t usart1,\\n\\t\\t\\t                    usart0_t usart0, twi_t twi)\\n{\\n\\t// Temporary clock source variable\\n\\tunsigned char clockSource = 0;\\n\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n\\t\\t// Store current setting\\n        clockSource = TCCR2B;\\n\\n\\t\\t// Remove the clock source to shutdown Timer2\\n\\t\\tTCCR2B &= ~(1 << CS22);\\n\\t\\tTCCR2B &= ~(1 << CS21);\\n\\t\\tTCCR2B &= ~(1 << CS20);\\n\\n\\t\\tpower_timer2_disable();\\n\\t}\\n\\n\\tif (adc == ADC_OFF)\\n\\t{\\n\\t\\tADCSRA &= ~(1 << ADEN);\\n\\t\\tpower_adc_disable();\\n\\t}\\n\\n\\tif (timer5 == TIMER5_OFF)\\tpower_timer5_disable();\\n\\tif (timer4 == TIMER4_OFF)\\tpower_timer4_disable();\\n\\tif (timer3 == TIMER3_OFF)\\tpower_timer3_disable();\\n\\tif (timer1 == TIMER1_OFF)\\tpower_timer1_disable();\\n\\tif (timer0 == TIMER0_OFF)\\tpower_timer0_disable();\\n\\tif (spi == SPI_OFF)\\t\\t\\t  power_spi_disable();\\n\\tif (usart1 == USART1_OFF)\\tpower_usart1_disable();\\n\\tif (usart0 == USART0_OFF)\\tpower_usart0_disable();\\n\\tif (twi == TWI_OFF)\\t\\t\\t  power_twi_disable();\\n\\n\\tif (period != SLEEP_FOREVER)\\n\\t{\\n\\t\\twdt_enable(period);\\n\\t\\tWDTCSR |= (1 << WDIE);\\n\\t}\\n\\n\\tlowPowerBodOn(SLEEP_MODE_IDLE);\\n\\n\\tif (adc == ADC_OFF)\\n\\t{\\n\\t\\tpower_adc_enable();\\n\\t\\tADCSRA |= (1 << ADEN);\\n\\t}\\n\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n        // Restore previous setting\\n        TCCR2B = clockSource;\\n\\n\\t\\tpower_timer2_enable();\\n\\t}\\n\\n\\tif (timer5 == TIMER5_OFF)\\tpower_timer5_enable();\\n\\tif (timer4 == TIMER4_OFF)\\tpower_timer4_enable();\\n\\tif (timer3 == TIMER3_OFF)\\tpower_timer3_enable();\\n\\tif (timer1 == TIMER1_OFF)\\tpower_timer1_enable();\\n\\tif (timer0 == TIMER0_OFF)\\tpower_timer0_enable();\\n\\tif (spi == SPI_OFF)\\t\\t\\t  power_spi_enable();\\n\\tif (usart1 == USART1_OFF)\\tpower_usart1_enable();\\n\\tif (usart0 == USART0_OFF)\\tpower_usart0_enable();\\n\\tif (twi == TWI_OFF)\\t\\t\\t  power_twi_enable();\\n}\\n#endif\\n\\n\\n/*******************************************************************************\\n* Name: adcNoiseReduction\\n* Description: Putting microcontroller into ADC noise reduction state. This is\\n*\\t\\t\\t   a very useful state when using the ADC to achieve best and low\\n*              noise signal.\\n*\\n* Argument  \\tDescription\\n* =========  \\t===========\\n* 1. period     Duration of low power mode. Use SLEEP_FOREVER to use other wake\\n*\\t\\t\\t\\tup resource:\\n*\\t\\t\\t\\t(a) SLEEP_15MS - 15 ms sleep\\n*\\t\\t\\t\\t(b) SLEEP_30MS - 30 ms sleep\\n*\\t\\t\\t\\t(c) SLEEP_60MS - 60 ms sleep\\n*\\t\\t\\t\\t(d) SLEEP_120MS - 120 ms sleep\\n*\\t\\t\\t\\t(e) SLEEP_250MS - 250 ms sleep\\n*\\t\\t\\t\\t(f) SLEEP_500MS - 500 ms sleep\\n*\\t\\t\\t\\t(g) SLEEP_1S - 1 s sleep\\n*\\t\\t\\t\\t(h) SLEEP_2S - 2 s sleep\\n*\\t\\t\\t\\t(i) SLEEP_4S - 4 s sleep\\n*\\t\\t\\t\\t(j) SLEEP_8S - 8 s sleep\\n*\\t\\t\\t\\t(k) SLEEP_FOREVER - Sleep without waking up through WDT\\n*\\n* 2. adc\\t\\tADC module disable control. Turning off the ADC module is\\n*\\t\\t\\t\\tbasically removing the purpose of this low power mode.\\n*\\t\\t\\t\\t(a) ADC_OFF - Turn off ADC module\\n*\\t\\t\\t\\t(b) ADC_ON - Leave ADC module in its default state\\n*\\n* 3. timer2\\t\\tTimer 2 module disable control:\\n*\\t\\t\\t\\t(a) TIMER2_OFF - Turn off Timer 2 module\\n*\\t\\t\\t\\t(b) TIMER2_ON - Leave Timer 2 module in its default state\\n*\\n*******************************************************************************/\\nvoid\\tLowPowerClass::adcNoiseReduction(period_t period, adc_t adc,\\n\\t\\t\\t\\t\\t\\t\\t\\t\\t\\t timer2_t timer2)\\n{\\n\\t// Temporary clock source variable\\n\\tunsigned char clockSource = 0;\\n\\n\\t#if !defined(__AVR_ATmega32U4__)\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n\\t\\t// Store current setting\\n        clockSource = TCCR2B;\\n\\n\\t\\t// Remove the clock source to shutdown Timer2\\n\\t\\tTCCR2B &= ~(1 << CS22);\\n\\t\\tTCCR2B &= ~(1 << CS21);\\n\\t\\tTCCR2B &= ~(1 << CS20);\\n\\t}\\n\\t#endif\\n\\n\\tif (adc == ADC_OFF)\\tADCSRA &= ~(1 << ADEN);\\n\\n\\tif (period != SLEEP_FOREVER)\\n\\t{\\n\\t\\twdt_enable(period);\\n\\t\\tWDTCSR |= (1 << WDIE);\\n\\t}\\n\\n\\tlowPowerBodOn(SLEEP_MODE_ADC);\\n\\n\\tif (adc == ADC_OFF) ADCSRA |= (1 << ADEN);\\n\\n\\t#if !defined(__AVR_ATmega32U4__)\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n        // Restore previous setting\\n        TCCR2B = clockSource;\\n\\t}\\n\\t#endif\\n}\\n\\n/*******************************************************************************\\n* Name: powerDown\\n* Description: Putting microcontroller into power down state. This is\\n*\\t\\t\\t   the lowest current consumption state. Use this together with\\n*\\t\\t\\t   external pin interrupt to wake up through external event\\n*\\t\\t\\t   triggering (example: RTC clockout pin, SD card detect pin).\\n*\\n* Argument  \\tDescription\\n* =========  \\t===========\\n* 1. period     Duration of low power mode. Use SLEEP_FOREVER to use other wake\\n*\\t\\t\\t\\tup resource:\\n*\\t\\t\\t\\t(a) SLEEP_15MS - 15 ms sleep\\n*\\t\\t\\t\\t(b) SLEEP_30MS - 30 ms sleep\\n*\\t\\t\\t\\t(c) SLEEP_60MS - 60 ms sleep\\n*\\t\\t\\t\\t(d) SLEEP_120MS - 120 ms sleep\\n*\\t\\t\\t\\t(e) SLEEP_250MS - 250 ms sleep\\n*\\t\\t\\t\\t(f) SLEEP_500MS - 500 ms sleep\\n*\\t\\t\\t\\t(g) SLEEP_1S - 1 s sleep\\n*\\t\\t\\t\\t(h) SLEEP_2S - 2 s sleep\\n*\\t\\t\\t\\t(i) SLEEP_4S - 4 s sleep\\n*\\t\\t\\t\\t(j) SLEEP_8S - 8 s sleep\\n*\\t\\t\\t\\t(k) SLEEP_FOREVER - Sleep without waking up through WDT\\n*\\n* 2. adc\\t\\tADC module disable control. Turning off the ADC module is\\n*\\t\\t\\t\\tbasically removing the purpose of this low power mode.\\n*\\t\\t\\t\\t(a) ADC_OFF - Turn off ADC module\\n*\\t\\t\\t\\t(b) ADC_ON - Leave ADC module in its default state\\n*\\n* 3. bod\\t\\tBrown Out Detector (BOD) module disable control:\\n*\\t\\t\\t\\t(a) BOD_OFF - Turn off BOD module\\n*\\t\\t\\t\\t(b) BOD_ON - Leave BOD module in its default state\\n*\\n*******************************************************************************/\\nvoid\\tLowPowerClass::powerDown(period_t period, adc_t adc, bod_t bod)\\n{\\n\\tif (adc == ADC_OFF)\\tADCSRA &= ~(1 << ADEN);\\n\\n\\tif (period != SLEEP_FOREVER)\\n\\t{\\n\\t\\twdt_enable(period);\\n\\t\\tWDTCSR |= (1 << WDIE);\\n\\t}\\n\\tif (bod == BOD_OFF)\\n\\t{\\n\\t\\t#if defined (__AVR_ATmega328P__) || defined (__AVR_ATmega168P__) || defined(__AVR_ATmega644P__) || defined(__AVR_ATmega1284P__)\\n\\t\\t\\tlowPowerBodOff(SLEEP_MODE_PWR_DOWN);\\n\\t\\t#else\\n\\t\\t\\tlowPowerBodOn(SLEEP_MODE_PWR_DOWN);\\n\\t\\t#endif\\n\\t}\\n\\telse\\n\\t{\\n\\t\\tlowPowerBodOn(SLEEP_MODE_PWR_DOWN);\\n\\t}\\n\\n\\tif (adc == ADC_OFF) ADCSRA |= (1 << ADEN);\\n}\\n\\n/*******************************************************************************\\n* Name: powerSave\\n* Description: Putting microcontroller into power save state. This is\\n*\\t\\t\\t   the lowest current consumption state after power down.\\n*\\t\\t\\t   Use this state together with an external 32.768 kHz crystal (but\\n*\\t\\t\\t   8/16 MHz crystal/resonator need to be removed) to provide an\\n*\\t\\t\\t   asynchronous clock source to Timer 2. Please take note that\\n*\\t\\t\\t   Timer 2 is also used by the Arduino core for PWM operation.\\n*\\t\\t\\t   Please refer to wiring.c for explanation. Removal of the external\\n*\\t\\t\\t   8/16 MHz crystal/resonator requires the microcontroller to run\\n*\\t\\t\\t   on its internal RC oscillator which is not so accurate for time\\n*\\t\\t\\t   critical operation.\\n*\\n* Argument  \\tDescription\\n* =========  \\t===========\\n* 1. period   Duration of low power mode. Use SLEEP_FOREVER to use other wake\\n*\\t\\t\\t\\tup resource:\\n*\\t\\t\\t\\t(a) SLEEP_15MS - 15 ms sleep\\n*\\t\\t\\t\\t(b) SLEEP_30MS - 30 ms sleep\\n*\\t\\t\\t\\t(c) SLEEP_60MS - 60 ms sleep\\n*\\t\\t\\t\\t(d) SLEEP_120MS - 120 ms sleep\\n*\\t\\t\\t\\t(e) SLEEP_250MS - 250 ms sleep\\n*\\t\\t\\t\\t(f) SLEEP_500MS - 500 ms sleep\\n*\\t\\t\\t\\t(g) SLEEP_1S - 1 s sleep\\n*\\t\\t\\t\\t(h) SLEEP_2S - 2 s sleep\\n*\\t\\t\\t\\t(i) SLEEP_4S - 4 s sleep\\n*\\t\\t\\t\\t(j) SLEEP_8S - 8 s sleep\\n*\\t\\t\\t\\t(k) SLEEP_FOREVER - Sleep without waking up through WDT\\n*\\n* 2. adc\\t\\tADC module disable control. Turning off the ADC module is\\n*\\t\\t\\t\\tbasically removing the purpose of this low power mode.\\n*\\t\\t\\t\\t(a) ADC_OFF - Turn off ADC module\\n*\\t\\t\\t\\t(b) ADC_ON - Leave ADC module in its default state\\n*\\n* 3. bod\\t\\tBrown Out Detector (BOD) module disable control:\\n*\\t\\t\\t\\t(a) BOD_OFF - Turn off BOD module\\n*\\t\\t\\t\\t(b) BOD_ON - Leave BOD module in its default state\\n*\\n* 4. timer2\\t\\tTimer 2 module disable control:\\n*\\t\\t\\t\\t(a) TIMER2_OFF - Turn off Timer 2 module\\n*\\t\\t\\t\\t(b) TIMER2_ON - Leave Timer 2 module in its default state\\n*\\n*******************************************************************************/\\nvoid\\tLowPowerClass::powerSave(period_t period, adc_t adc, bod_t bod,\\n\\t\\t\\t\\t\\t\\t\\t     timer2_t timer2)\\n{\\n\\t// Temporary clock source variable\\n\\tunsigned char clockSource = 0;\\n\\n\\t#if !defined(__AVR_ATmega32U4__)\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n\\t\\t// Store current setting\\n        clockSource = TCCR2B;\\n\\n\\t\\t// Remove the clock source to shutdown Timer2\\n\\t\\tTCCR2B &= ~(1 << CS22);\\n\\t\\tTCCR2B &= ~(1 << CS21);\\n\\t\\tTCCR2B &= ~(1 << CS20);\\n\\t}\\n\\t#endif\\n\\n\\tif (adc == ADC_OFF)\\tADCSRA &= ~(1 << ADEN);\\n\\n\\tif (period != SLEEP_FOREVER)\\n\\t{\\n\\t\\twdt_enable(period);\\n\\t\\tWDTCSR |= (1 << WDIE);\\n\\t}\\n\\n\\tif (bod == BOD_OFF)\\n\\t{\\n\\t\\t#if defined (__AVR_ATmega328P__) || defined (__AVR_ATmega168P__) || defined(__AVR_ATmega644P__) || defined(__AVR_ATmega1284P__)\\n\\t\\t\\tlowPowerBodOff(SLEEP_MODE_PWR_SAVE);\\n\\t\\t#else\\n\\t\\t\\tlowPowerBodOn(SLEEP_MODE_PWR_SAVE);\\n\\t\\t#endif\\n\\t}\\n\\telse\\n\\t{\\n\\t\\tlowPowerBodOn(SLEEP_MODE_PWR_SAVE);\\n\\t}\\n\\n\\tif (adc == ADC_OFF) ADCSRA |= (1 << ADEN);\\n\\n\\t#if !defined(__AVR_ATmega32U4__)\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n        // Restore previous setting\\n        TCCR2B = clockSource;\\n\\t}\\n\\t#endif\\n}\\n\\n/*******************************************************************************\\n* Name: powerStandby\\n* Description: Putting microcontroller into power standby state.\\n*\\n* Argument  \\tDescription\\n* =========  \\t===========\\n* 1. period     Duration of low power mode. Use SLEEP_FOREVER to use other wake\\n*\\t\\t\\t\\tup resource:\\n*\\t\\t\\t\\t(a) SLEEP_15MS - 15 ms sleep\\n*\\t\\t\\t\\t(b) SLEEP_30MS - 30 ms sleep\\n*\\t\\t\\t\\t(c) SLEEP_60MS - 60 ms sleep\\n*\\t\\t\\t\\t(d) SLEEP_120MS - 120 ms sleep\\n*\\t\\t\\t\\t(e) SLEEP_250MS - 250 ms sleep\\n*\\t\\t\\t\\t(f) SLEEP_500MS - 500 ms sleep\\n*\\t\\t\\t\\t(g) SLEEP_1S - 1 s sleep\\n*\\t\\t\\t\\t(h) SLEEP_2S - 2 s sleep\\n*\\t\\t\\t\\t(i) SLEEP_4S - 4 s sleep\\n*\\t\\t\\t\\t(j) SLEEP_8S - 8 s sleep\\n*\\t\\t\\t\\t(k) SLEEP_FOREVER - Sleep without waking up through WDT\\n*\\n* 2. adc\\t\\tADC module disable control. Turning off the ADC module is\\n*\\t\\t\\t\\tbasically removing the purpose of this low power mode.\\n*\\t\\t\\t\\t(a) ADC_OFF - Turn off ADC module\\n*\\t\\t\\t\\t(b) ADC_ON - Leave ADC module in its default state\\n*\\n* 3. bod\\t\\tBrown Out Detector (BOD) module disable control:\\n*\\t\\t\\t\\t(a) BOD_OFF - Turn off BOD module\\n*\\t\\t\\t\\t(b) BOD_ON - Leave BOD module in its default state\\n*\\n*******************************************************************************/\\nvoid\\tLowPowerClass::powerStandby(period_t period, adc_t adc, bod_t bod)\\n{\\n\\tif (adc == ADC_OFF)\\tADCSRA &= ~(1 << ADEN);\\n\\n\\tif (period != SLEEP_FOREVER)\\n\\t{\\n\\t\\twdt_enable(period);\\n\\t\\tWDTCSR |= (1 << WDIE);\\n\\t}\\n\\n\\tif (bod == BOD_OFF)\\n\\t{\\n\\t\\t#if defined (__AVR_ATmega328P__) || defined (__AVR_ATmega168P__) || defined(__AVR_ATmega644P__) || defined(__AVR_ATmega1284P__)\\n\\t\\t\\tlowPowerBodOff(SLEEP_MODE_STANDBY);\\n\\t\\t#else\\n\\t\\t\\tlowPowerBodOn(SLEEP_MODE_STANDBY);\\n\\t\\t#endif\\n\\t}\\n\\telse\\n\\t{\\n\\t\\tlowPowerBodOn(SLEEP_MODE_STANDBY);\\n\\t}\\n\\n\\tif (adc == ADC_OFF) ADCSRA |= (1 << ADEN);\\n}\\n\\n/*******************************************************************************\\n* Name: powerExtStandby\\n* Description: Putting microcontroller into power extended standby state. This\\n*\\t\\t\\t   is different from the power standby state as it has the\\n*\\t\\t\\t   capability to run Timer 2 asynchronously.\\n*              Not implemented on Atmega88 and Atmega168.\\n*\\n* Argument  \\tDescription\\n* =========  \\t===========\\n* 1. period     Duration of low power mode. Use SLEEP_FOREVER to use other wake\\n*\\t\\t\\t\\tup resource:\\n*\\t\\t\\t\\t(a) SLEEP_15MS - 15 ms sleep\\n*\\t\\t\\t\\t(b) SLEEP_30MS - 30 ms sleep\\n*\\t\\t\\t\\t(c) SLEEP_60MS - 60 ms sleep\\n*\\t\\t\\t\\t(d) SLEEP_120MS - 120 ms sleep\\n*\\t\\t\\t\\t(e) SLEEP_250MS - 250 ms sleep\\n*\\t\\t\\t\\t(f) SLEEP_500MS - 500 ms sleep\\n*\\t\\t\\t\\t(g) SLEEP_1S - 1 s sleep\\n*\\t\\t\\t\\t(h) SLEEP_2S - 2 s sleep\\n*\\t\\t\\t\\t(i) SLEEP_4S - 4 s sleep\\n*\\t\\t\\t\\t(j) SLEEP_8S - 8 s sleep\\n*\\t\\t\\t\\t(k) SLEEP_FOREVER - Sleep without waking up through WDT\\n*\\n* 2. adc\\t\\tADC module disable control.\\n*\\t\\t\\t\\t(a) ADC_OFF - Turn off ADC module\\n*\\t\\t\\t\\t(b) ADC_ON - Leave ADC module in its default state\\n*\\n* 3. bod\\t\\tBrown Out Detector (BOD) module disable control:\\n*\\t\\t\\t\\t(a) BOD_OFF - Turn off BOD module\\n*\\t\\t\\t\\t(b) BOD_ON - Leave BOD module in its default state\\n*\\n* 4. timer2\\t\\tTimer 2 module disable control:\\n*\\t\\t\\t\\t(a) TIMER2_OFF - Turn off Timer 2 module\\n*\\t\\t\\t\\t(b) TIMER2_ON - Leave Timer 2 module in its default state\\n*\\n*******************************************************************************/\\nvoid\\tLowPowerClass::powerExtStandby(period_t period, adc_t adc, bod_t bod,\\n\\t\\t\\t\\t\\t\\t\\t\\t\\t   timer2_t timer2)\\n{\\n\\t// Temporary clock source variable\\n\\tunsigned char clockSource = 0;\\n\\n\\t#if !defined(__AVR_ATmega32U4__)\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n\\t\\t// Store current setting\\n        clockSource = TCCR2B;\\n\\n\\t\\t// Remove the clock source to shutdown Timer2\\n\\t\\tTCCR2B &= ~(1 << CS22);\\n\\t\\tTCCR2B &= ~(1 << CS21);\\n\\t\\tTCCR2B &= ~(1 << CS20);\\n\\t}\\n\\t#endif\\n\\n\\tif (adc == ADC_OFF)\\tADCSRA &= ~(1 << ADEN);\\n\\n\\tif (period != SLEEP_FOREVER)\\n\\t{\\n\\t\\twdt_enable(period);\\n\\t\\tWDTCSR |= (1 << WDIE);\\n\\t}\\n\\n\\n\\t#if defined (__AVR_ATmega88__) || defined (__AVR_ATmega168__) // SLEEP_MODE_EXT_STANDBY not implemented on Atmega88 / Atmega168\\n\\t#else\\n\\t\\tif (bod == BOD_OFF)\\n\\t\\t{\\n\\t\\t\\t#if defined (__AVR_ATmega328P__) || defined (__AVR_ATmega168P__) || defined(__AVR_ATmega644P__) || defined(__AVR_ATmega1284P__)\\n\\t\\t\\t\\tlowPowerBodOff(SLEEP_MODE_EXT_STANDBY);\\n\\t\\t\\t#else\\n\\t\\t\\t\\tlowPowerBodOn(SLEEP_MODE_EXT_STANDBY);\\n\\t\\t\\t#endif\\n\\t\\t}\\n\\t\\telse\\n\\t\\t{\\n\\t\\t\\tlowPowerBodOn(SLEEP_MODE_EXT_STANDBY);\\n\\t\\t}\\n\\t#endif\\n\\n\\tif (adc == ADC_OFF) ADCSRA |= (1 << ADEN);\\n\\n\\t#if !defined(__AVR_ATmega32U4__)\\n\\tif (timer2 == TIMER2_OFF)\\n\\t{\\n        // Restore previous setting\\n        TCCR2B = clockSource;\\n\\t}\\n\\t#endif\\n}\\n\\n// sleep # of milliseconds using WDT (watchdog timer - accurate to within 10%, uses about 3uA)\\nvoid LowPowerClass::longPowerDown(uint32_t sleepTime) {\\n  do {\\n    if (sleepTime > 8000)\\n    {\\n      powerDown(SLEEP_8S, ADC_OFF, BOD_OFF);\\n      sleepTime-=8000;\\n    }\\n    else if (sleepTime > 4000)\\n    {\\n      powerDown(SLEEP_4S, ADC_OFF, BOD_OFF);\\n      sleepTime-=4000;\\n    }\\n    else if (sleepTime > 2000)\\n    {\\n      powerDown(SLEEP_2S, ADC_OFF, BOD_OFF);\\n      sleepTime-=2000;\\n    }\\n    else if (sleepTime > 1000)\\n    {\\n      powerDown(SLEEP_1S, ADC_OFF, BOD_OFF);\\n      sleepTime-=1000;\\n    }\\n    else if (sleepTime > 512)\\n    {\\n      powerDown(SLEEP_500MS, ADC_OFF, BOD_OFF);\\n      sleepTime-=512;\\n    }\\n    else if (sleepTime > 256)\\n    {\\n      powerDown(SLEEP_250MS, ADC_OFF, BOD_OFF);\\n      sleepTime-=256;\\n    }\\n    else if (sleepTime > 128)\\n    {\\n      powerDown(SLEEP_120MS, ADC_OFF, BOD_OFF);\\n      sleepTime-=128;\\n    }\\n    else if (sleepTime > 64)\\n    {\\n      powerDown(SLEEP_60MS, ADC_OFF, BOD_OFF);\\n      sleepTime-=64;\\n    }\\n    else if (sleepTime > 32)\\n    {\\n      powerDown(SLEEP_30MS, ADC_OFF, BOD_OFF);\\n      sleepTime-=32;\\n    }\\n    else if (sleepTime > 16)\\n    {\\n      powerDown(SLEEP_15MS, ADC_OFF, BOD_OFF);\\n      sleepTime-=16;\\n    }\\n    else\\n    {\\n      sleepTime=0;\\n    }\\n  } while(sleepTime);\\n}\\n\\n/*******************************************************************************\\n* Name: ISR (WDT_vect)\\n* Description: Watchdog Timer interrupt service routine. This routine is\\n*\\t\\t       required to allow automatic WDIF and WDIE bit clearance in\\n*\\t\\t\\t   hardware.\\n*\\n*******************************************************************************/\\nISR (WDT_vect)\\n{\\n\\t// WDIE & WDIF is cleared in hardware upon entering this ISR\\n\\twdt_disable();\\n}\\n\\n#elif defined(__arm__)\\n#if defined(__SAMD21__) || defined(ARDUINO_SAMD_ZERO)\\n/*******************************************************************************\\n* Name: standby\\n* Description: Putting SAMD21G18A into idle mode. This is the lowest current\\n*              consumption mode. Requires separate handling of clock and\\n* \\t\\t\\t   peripheral management (disabling and shutting down) to achieve\\n* \\t\\t\\t   the desired current consumption.\\n*\\n* Argument  \\tDescription\\n* =========  \\t===========\\n* 1. idleMode   Idle mode level (0, 1, 2) where IDLE_2 level provide lowest\\n* \\t\\t\\t\\tcurrent consumption in this mode.\\n*\\n*******************************************************************************/\\nvoid\\tLowPowerClass::idle(idle_t idleMode)\\n{\\n\\tSCB->SCR &= ~SCB_SCR_SLEEPDEEP_Msk;\\n\\tPM->SLEEP.reg = idleMode;\\n\\t__DSB();\\n\\t__WFI();\\n}\\n\\n/*******************************************************************************\\n* Name: standby\\n* Description: Putting SAMD21G18A into standby mode. This is the lowest current\\n*              consumption mode. Use this together with the built-in RTC (use\\n*              RTCZero library) or external pin interrupt to wake up through\\n*              external event triggering.\\n*\\n* Argument  \\tDescription\\n* =========  \\t===========\\n* 1. NIL\\n*\\n*******************************************************************************/\\nvoid\\tLowPowerClass::standby()\\n{\\n\\tSCB->SCR |= SCB_SCR_SLEEPDEEP_Msk;\\n\\t__DSB();\\n\\t__WFI();\\n}\\n\\n#else\\n\\t#error \\\"Please ensure chosen MCU is a SAMD21\\\"\\n#endif\\n#else\\n\\t#error \\\"Processor architecture is not supported.\\\"\\n#endif\\n\\nLowPowerClass LowPower;\" }",
    "{ filename: \"src/LowPower.h\", code: \"#ifndef LowPower_h\\n#define LowPower_h\\n\\n#include \\\"Arduino.h\\\"\\n\\nenum period_t\\n{\\n\\tSLEEP_15MS,\\n\\tSLEEP_30MS,\\n\\tSLEEP_60MS,\\n\\tSLEEP_120MS,\\n\\tSLEEP_250MS,\\n\\tSLEEP_500MS,\\n\\tSLEEP_1S,\\n\\tSLEEP_2S,\\n\\tSLEEP_4S,\\n\\tSLEEP_8S,\\n\\tSLEEP_FOREVER\\n};\\n\\nenum bod_t\\n{\\n\\tBOD_OFF,\\n\\tBOD_ON\\n};\\n\\nenum adc_t\\n{\\n\\tADC_OFF,\\n\\tADC_ON\\n};\\n\\nenum timer5_t\\n{\\n\\tTIMER5_OFF,\\n\\tTIMER5_ON\\n};\\n\\nenum timer4_t\\n{\\n\\tTIMER4_OFF,\\n\\tTIMER4_ON\\n};\\n\\nenum timer3_t\\n{\\n\\tTIMER3_OFF,\\n\\tTIMER3_ON\\n};\\n\\nenum timer2_t\\n{\\n\\tTIMER2_OFF,\\n\\tTIMER2_ON\\n};\\n\\nenum timer1_t\\n{\\n\\tTIMER1_OFF,\\n\\tTIMER1_ON\\n};\\n\\nenum timer0_t\\n{\\n\\tTIMER0_OFF,\\n\\tTIMER0_ON\\n};\\n\\nenum spi_t\\n{\\n\\tSPI_OFF,\\n\\tSPI_ON\\n};\\n\\nenum usart0_t\\n{\\n\\tUSART0_OFF,\\n\\tUSART0_ON\\n};\\n\\nenum usart1_t\\n{\\n\\tUSART1_OFF,\\n\\tUSART1_ON\\n};\\n\\nenum usart2_t\\n{\\n\\tUSART2_OFF,\\n\\tUSART2_ON\\n};\\n\\nenum usart3_t\\n{\\n\\tUSART3_OFF,\\n\\tUSART3_ON\\n};\\n\\nenum twi_t\\n{\\n\\tTWI_OFF,\\n\\tTWI_ON\\n};\\n\\nenum usb_t\\n{\\n\\tUSB_OFF,\\n\\tUSB_ON\\n};\\n\\nenum idle_t\\n{\\n\\tIDLE_0,\\n\\tIDLE_1,\\n\\tIDLE_2\\n};\\n\\nclass LowPowerClass\\n{\\n\\tpublic:\\n\\t\\t#if defined (__AVR__)\\n\\n\\t\\t\\t#if defined (__AVR_ATmega328P__) || defined (__AVR_ATmega168__) || defined (__AVR_ATmega168P__) || defined (__AVR_ATmega88__)\\n\\t\\t\\t\\tvoid\\tidle(period_t period, adc_t adc, timer2_t timer2,\\n\\t\\t\\t\\t\\t\\t     timer1_t timer1, timer0_t timer0, spi_t spi,\\n\\t\\t\\t\\t\\t         usart0_t usart0, twi_t twi);\\n\\t\\t\\t#elif defined __AVR_ATmega644P__ || defined (__AVR_ATmega1284P__)\\n\\t\\t\\t\\tvoid\\tidle(period_t period, adc_t adc, timer2_t timer2,\\n\\t\\t\\t\\t\\t\\t\\t timer1_t timer1, timer0_t timer0, spi_t spi,\\n\\t\\t\\t\\t\\t\\t\\t usart1_t usart1, usart0_t usart0, twi_t twi);\\n\\t\\t\\t#elif defined __AVR_ATmega2560__\\n\\t\\t\\t\\tvoid\\tidle(period_t period, adc_t adc, timer5_t timer5,\\n\\t\\t\\t\\t\\t\\t\\t timer4_t timer4, timer3_t timer3, timer2_t timer2,\\n\\t\\t\\t\\t\\t\\t\\t timer1_t timer1, timer0_t timer0, spi_t spi,\\n\\t\\t\\t\\t\\t\\t\\t usart3_t usart3, usart2_t usart2, usart1_t usart1,\\n\\t\\t\\t\\t\\t\\t\\t usart0_t usart0, twi_t twi);\\n\\t\\t\\t#elif defined __AVR_ATmega256RFR2__\\n\\t\\t\\t\\tvoid\\tidle(period_t period, adc_t adc, timer5_t timer5,\\n\\t\\t\\t\\t\\t\\t\\t\\t\\t timer4_t timer4, timer3_t timer3, timer2_t timer2,\\n\\t\\t\\t\\t   \\t\\t\\t\\t timer1_t timer1, timer0_t timer0, spi_t spi,\\n\\t\\t\\t\\t\\t\\t       usart1_t usart1,\\n\\t\\t\\t\\t\\t\\t\\t\\t\\t usart0_t usart0, twi_t twi);\\n\\t\\t\\t#elif defined __AVR_ATmega32U4__\\n\\t\\t\\t\\tvoid\\tidle(period_t period, adc_t adc, timer4_t timer4,\\n\\t\\t\\t\\t             timer3_t timer3, timer1_t timer1, timer0_t timer0,\\n\\t\\t\\t\\t             spi_t spi, usart1_t usart1, twi_t twi, usb_t usb);\\n\\t\\t\\t#else\\n\\t\\t\\t\\t#error \\\"Please ensure chosen MCU is either 88, 168, 168P, 328P, 32U4, 2560 or 256RFR2.\\\"\\n\\t\\t\\t#endif\\n\\t\\t\\tvoid\\tadcNoiseReduction(period_t period, adc_t adc, timer2_t timer2) __attribute__((optimize(\\\"-O1\\\")));\\n\\t\\t\\tvoid\\tpowerDown(period_t period, adc_t adc, bod_t bod) __attribute__((optimize(\\\"-O1\\\")));\\n\\t\\t\\tvoid\\tpowerSave(period_t period, adc_t adc, bod_t bod, timer2_t timer2) __attribute__((optimize(\\\"-O1\\\")));\\n\\t\\t\\tvoid\\tpowerStandby(period_t period, adc_t adc, bod_t bod) __attribute__((optimize(\\\"-O1\\\")));\\n\\t\\t\\tvoid\\tpowerExtStandby(period_t period, adc_t adc, bod_t bod, timer2_t timer2) __attribute__((optimize(\\\"-O1\\\")));\\n      void  longPowerDown(uint32_t sleepTime);\\n\\t\\t#elif defined (__arm__)\\n\\t\\t\\t#if defined(__SAMD21__) || defined(ARDUINO_SAMD_ZERO)\\n\\t\\t\\t\\tvoid\\tidle(idle_t idleMode);\\n\\t\\t\\t\\tvoid\\tstandby();\\n\\t\\t\\t#else\\n\\t\\t\\t\\t#error \\\"Please ensure chosen MCU is a SAMD21\\\"\\n\\t\\t\\t#endif\\n\\n\\t\\t#else\\n\\n\\t\\t\\t#error \\\"Processor architecture is not supported.\\\"\\n\\n\\t\\t#endif\\n};\\n\\nextern LowPowerClass LowPower;\\n#endif\" }"
];